@@ -1,6 +1,6 @@
 /* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
-//@line 44 "/builds/moz2_slave/2.0-linuxqt-xr/build/toolkit/mozapps/update/nsUpdateService.js"
+//@line 44 "/builds/slave/beta-lnx-xr/build/toolkit/mozapps/update/nsUpdateService.js"
 */
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 Components.utils.import("resource://gre/modules/FileUtils.jsm");
@@ -22,6 +22,7 @@ const PREF_APP_UPDATE_CERT_ERRORS         = "app.update.cert.errors";
 const PREF_APP_UPDATE_CERT_MAXERRORS      = "app.update.cert.maxErrors";
 const PREF_APP_UPDATE_CERT_REQUIREBUILTIN = "app.update.cert.requireBuiltIn";
 const PREF_APP_UPDATE_CHANNEL             = "app.update.channel";
+const PREF_APP_UPDATE_DESIREDCHANNEL      = "app.update.desiredChannel";
 const PREF_APP_UPDATE_ENABLED             = "app.update.enabled";
 const PREF_APP_UPDATE_IDLETIME            = "app.update.idletime";
 const PREF_APP_UPDATE_INCOMPATIBLE_MODE   = "app.update.incompatible.mode";
@@ -52,16 +53,17 @@ const CATEGORY_UPDATE_TIMER               = "update-timer";
 const KEY_APPDIR          = "XCurProcD";
 const KEY_GRED            = "GreD";
 
-//@line 102 "/builds/moz2_slave/2.0-linuxqt-xr/build/toolkit/mozapps/update/nsUpdateService.js"
+//@line 103 "/builds/slave/beta-lnx-xr/build/toolkit/mozapps/update/nsUpdateService.js"
 
-//@line 106 "/builds/moz2_slave/2.0-linuxqt-xr/build/toolkit/mozapps/update/nsUpdateService.js"
+//@line 107 "/builds/slave/beta-lnx-xr/build/toolkit/mozapps/update/nsUpdateService.js"
 
 const DIR_UPDATES         = "updates";
+const FILE_CHANNELCHANGE  = "channelchange";
 const FILE_UPDATE_STATUS  = "update.status";
 const FILE_UPDATE_VERSION = "update.version";
-//@line 113 "/builds/moz2_slave/2.0-linuxqt-xr/build/toolkit/mozapps/update/nsUpdateService.js"
+//@line 115 "/builds/slave/beta-lnx-xr/build/toolkit/mozapps/update/nsUpdateService.js"
 const FILE_UPDATE_ARCHIVE = "update.mar";
-//@line 115 "/builds/moz2_slave/2.0-linuxqt-xr/build/toolkit/mozapps/update/nsUpdateService.js"
+//@line 117 "/builds/slave/beta-lnx-xr/build/toolkit/mozapps/update/nsUpdateService.js"
 const FILE_UPDATE_LOG     = "update.log"
 const FILE_UPDATES_DB     = "updates.xml";
 const FILE_UPDATE_ACTIVE  = "active-update.xml";
@@ -117,7 +119,7 @@ XPCOMUtils.defineLazyGetter(this, "gABI", function aus_gABI() {
   catch (e) {
     LOG("gABI - XPCOM ABI unknown: updates are not possible.");
   }
-//@line 179 "/builds/moz2_slave/2.0-linuxqt-xr/build/toolkit/mozapps/update/nsUpdateService.js"
+//@line 181 "/builds/slave/beta-lnx-xr/build/toolkit/mozapps/update/nsUpdateService.js"
   return abi;
 });
 
@@ -153,7 +155,7 @@ XPCOMUtils.defineLazyGetter(this, "gCanApplyUpdates", function aus_gCanApplyUpda
       updateTestFile.remove(false);
     updateTestFile.create(NORMAL_FILE_TYPE, FileUtils.PERMS_FILE);
     updateTestFile.remove(false);
-//@line 288 "/builds/moz2_slave/2.0-linuxqt-xr/build/toolkit/mozapps/update/nsUpdateService.js"
+//@line 290 "/builds/slave/beta-lnx-xr/build/toolkit/mozapps/update/nsUpdateService.js"
   }
   catch (e) {
      LOG("gCanApplyUpdates - unable to apply updates. Exception: " + e);
@@ -206,7 +208,7 @@ function LOG(string) {
 }
 
 /**
-//@line 350 "/builds/moz2_slave/2.0-linuxqt-xr/build/toolkit/mozapps/update/nsUpdateService.js"
+//@line 352 "/builds/slave/beta-lnx-xr/build/toolkit/mozapps/update/nsUpdateService.js"
  */
 function getPref(func, preference, defaultValue) {
   try {
@@ -232,10 +234,10 @@ function binaryToHex(input) {
 }
 
 /**
-//@line 381 "/builds/moz2_slave/2.0-linuxqt-xr/build/toolkit/mozapps/update/nsUpdateService.js"
+//@line 383 "/builds/slave/beta-lnx-xr/build/toolkit/mozapps/update/nsUpdateService.js"
  */
 function getUpdateDirCreate(pathArray) {
-//@line 390 "/builds/moz2_slave/2.0-linuxqt-xr/build/toolkit/mozapps/update/nsUpdateService.js"
+//@line 392 "/builds/slave/beta-lnx-xr/build/toolkit/mozapps/update/nsUpdateService.js"
   return FileUtils.getDir(KEY_APPDIR, pathArray, true);
 }
 
@@ -323,7 +325,7 @@ function writeStatusFile(dir, state) {
 }
 
 /**
-//@line 490 "/builds/moz2_slave/2.0-linuxqt-xr/build/toolkit/mozapps/update/nsUpdateService.js"
+//@line 492 "/builds/slave/beta-lnx-xr/build/toolkit/mozapps/update/nsUpdateService.js"
  */
 function writeVersionFile(dir, version) {
   var versionFile = dir.clone();
@@ -331,6 +333,12 @@ function writeVersionFile(dir, version) {
   writeStringToFile(versionFile, version);
 }
 
+function createChannelChangeFile(dir) {
+  var channelChangeFile = dir.clone();
+  channelChangeFile.append(FILE_CHANNELCHANGE);
+  channelChangeFile.create(Ci.nsILocalFile.NORMAL_FILE_TYPE, FileUtils.PERMS_FILE);
+}
+
 /**
  * Removes the contents of the Updates Directory
  */
@@ -456,6 +464,19 @@ function getUpdateChannel() {
   return channel;
 }
 
+function getDesiredChannel() {
+  let desiredChannel = getPref("getCharPref", PREF_APP_UPDATE_DESIREDCHANNEL, null);
+  if (!desiredChannel)
+    return null;
+  
+  if (desiredChannel == getUpdateChannel()) {
+    Services.prefs.clearUserPref(PREF_APP_UPDATE_DESIREDCHANNEL);
+    return null;
+  }
+  LOG("getDesiredChannel - channel set to: " + desiredChannel);
+  return desiredChannel;
+}
+
 /* Get the distribution pref values, from defaults only */
 function getDistributionPrefValue(aPrefName) {
   var prefValue = "default";
@@ -960,6 +981,9 @@ const UpdateServiceFactory = {
  */
 function UpdateService() {
   Services.obs.addObserver(this, "xpcom-shutdown", false);
+  // This will clear the preference if the channel is the same as the
+  // application's channel.
+  getDesiredChannel();
 }
 
 UpdateService.prototype = {
@@ -1062,6 +1086,9 @@ UpdateService.prototype = {
 
       // Done with this update. Clean it up.
       cleanupActiveUpdate();
+
+      if (Services.prefs.prefHasUserValue(PREF_APP_UPDATE_DESIREDCHANNEL))      
+        Services.prefs.clearUserPref(PREF_APP_UPDATE_DESIREDCHANNEL);
     }
     else {
       // If we hit an error, then the error code will be included in the status
@@ -1079,12 +1106,10 @@ UpdateService.prototype = {
         if (update.errorCode == WRITE_ERROR) {
           prompter.showUpdateError(update);
           writeStatusFile(getUpdatesDir(), update.state = STATE_PENDING);
-          writeVersionFile(getUpdatesDir(), update.appVersion);
           return;
         }
         else if (update.errorCode == ELEVATION_CANCELED) {
           writeStatusFile(getUpdatesDir(), update.state = STATE_PENDING);
-          writeVersionFile(getUpdatesDir(), update.appVersion);
           return;
         }
       }
@@ -1187,6 +1212,12 @@ UpdateService.prototype = {
     if (updates.length == 0)
       return null;
 
+    if (getDesiredChannel()) {
+      LOG("Checker:selectUpdate - skipping version checks for change change " +
+          "request");
+      return updates[0];
+    }
+
     // Choose the newest of the available minor and major updates.
     var majorUpdate = null;
     var minorUpdate = null;
@@ -1276,7 +1307,7 @@ UpdateService.prototype = {
     }
 
     /**
-//@line 1466 "/builds/moz2_slave/2.0-linuxqt-xr/build/toolkit/mozapps/update/nsUpdateService.js"
+//@line 1497 "/builds/slave/beta-lnx-xr/build/toolkit/mozapps/update/nsUpdateService.js"
      */
     if (update.showPrompt) {
       LOG("Checker:_selectAndInstallUpdate - prompting because the update " +
@@ -1365,7 +1396,7 @@ UpdateService.prototype = {
 
       if (self._incompatibleAddons.length > 0) {
       /**
-//@line 1572 "/builds/moz2_slave/2.0-linuxqt-xr/build/toolkit/mozapps/update/nsUpdateService.js"
+//@line 1603 "/builds/slave/beta-lnx-xr/build/toolkit/mozapps/update/nsUpdateService.js"
        */
         self._updateCheckCount = self._incompatibleAddons.length;
         LOG("UpdateService:_checkAddonCompatibility - checking for " +
@@ -1498,7 +1529,7 @@ UpdateService.prototype = {
     // current application's version or the update's version is the same as the
     // application's version and the build ID is the same as the application's
     // build ID.
-    if (update.appVersion &&
+    if (!getDesiredChannel() && update.appVersion &&
         (Services.vc.compare(update.appVersion, Services.appinfo.version) < 0 ||
          update.buildID && update.buildID == Services.appinfo.appBuildID &&
          update.appVersion == Services.appinfo.version)) {
@@ -1699,8 +1730,9 @@ UpdateManager.prototype = {
    * See nsIUpdateService.idl
    */
   get activeUpdate() {
+    let currentChannel = getDesiredChannel() || getUpdateChannel();
     if (this._activeUpdate &&
-        this._activeUpdate.channel != getUpdateChannel()) {
+        this._activeUpdate.channel != currentChannel) {
       // User switched channels, clear out any old active updates and remove
       // partial downloads
       this._activeUpdate = null;
@@ -1875,6 +1907,10 @@ Checker.prototype = {
                       getDistributionPrefValue(PREF_APP_DISTRIBUTION_VERSION));
     url = url.replace(/\+/g, "%2B");
 
+    let desiredChannel = getDesiredChannel();
+    if (desiredChannel)
+      url += (url.indexOf("?") != -1 ? "&" : "?") + "newchannel=" + desiredChannel;
+
     if (force)
       url += (url.indexOf("?") != -1 ? "&" : "?") + "force=1";
 
@@ -1956,7 +1992,7 @@ Checker.prototype = {
         continue;
       }
       update.serviceURL = this.getUpdateURL(this._forced);
-      update.channel = getUpdateChannel();
+      update.channel = getDesiredChannel() || getUpdateChannel();
       updates.push(update);
     }
 
@@ -2224,7 +2260,7 @@ Downloader.prototype = {
 
     // If this is a patch that we know about, then select it.  If it is a patch
     // that we do not know about, then remove it and use our default logic.
-    var useComplete = false;
+    var useComplete = getDesiredChannel() ? true : false;
     if (selectedPatch) {
       LOG("Downloader:_selectPatch - found existing patch with state: " +
           state);
@@ -2470,6 +2506,8 @@ Downloader.prototype = {
         // Tell the updater.exe we're ready to apply.
         writeStatusFile(getUpdatesDir(), state);
         writeVersionFile(getUpdatesDir(), this._update.appVersion);
+        if (getDesiredChannel())
+          createChannelChangeFile(getUpdatesDir());
         this._update.installDate = (new Date()).getTime();
         this._update.statusText = gUpdateBundle.GetStringFromName("installPending");
       }
