@@ -1,4 +1,4 @@
-//@line 38 "/builds/moz2_slave/2.0-linuxqt-xr/build/toolkit/content/aboutSupport.js"
+//@line 38 "/builds/moz2_slave/beta-linuxqt-xr/build/toolkit/content/aboutSupport.js"
 
 const Cc = Components.classes;
 const Ci = Components.interfaces;
@@ -73,6 +73,16 @@ window.onload = function () {
 
 function populateExtensionsSection() {
   AddonManager.getAddonsByTypes(["extension"], function(extensions) {
+    extensions.sort(function(a,b) {
+      if (a.isActive != b.isActive)
+        return b.isActive ? 1 : -1;
+      let lc = a.name.localeCompare(b.name);
+      if (lc != 0)
+        return lc;
+      if (a.version != b.version)
+        return a.version > b.version ? 1 : -1;
+      return 0;
+    });
     let trExtensions = [];
     for (let i = 0; i < extensions.length; i++) {
       let extension = extensions[i];
@@ -379,7 +389,7 @@ function createTextForElement(elem) {
   text = text.replace(/\n\n\n+/g, "\n\n");
 
   // Actual CR/LF pairs are needed for some Windows text editors.
-//@line 421 "/builds/moz2_slave/2.0-linuxqt-xr/build/toolkit/content/aboutSupport.js"
+//@line 431 "/builds/moz2_slave/beta-linuxqt-xr/build/toolkit/content/aboutSupport.js"
 
   return text;
 }
